==> hudi-0.10.0.src.tgz: hudi-0.10.0/hudi-common/src/main/java/org/apache/hudi/exception/HoodieHeartbeatException.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.hudi.exception;

import java.io.Serializable;

/**
 * <p>
 * Exception thrown for Hoodie hearbeat failures. The root of the exception hierarchy.
 * </p>
 * <p>
 * Hoodie Write/Read clients will throw this exception if any of its operations fail. This is a runtime (unchecked)
 * exception.
 * </p>
 */
public class HoodieHeartbeatException extends RuntimeException implements Serializable {

  public HoodieHeartbeatException() {
    super();
  }

  public HoodieHeartbeatException(String message) {
    super(message);
  }

  public HoodieHeartbeatException(String message, Throwable t) {
    super(message, t);
  }

  public HoodieHeartbeatException(Throwable t) {
    super(t);
  }

}

==> hudi-0.15.0.src.tgz: hudi-0.15.0/hudi-common/src/main/java/org/apache/hudi/exception/HoodieHeartbeatException.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.hudi.exception;

import java.io.Serializable;

/**
 * <p>
 * Exception thrown for Hoodie heartbeat failures. The root of the exception hierarchy.
 * </p>
 * <p>
 * Hoodie Write/Read clients will throw this exception if any of its operations fail. This is a runtime (unchecked)
 * exception.
 * </p>
 */
public class HoodieHeartbeatException extends RuntimeException implements Serializable {

  public HoodieHeartbeatException() {
    super();
  }

  public HoodieHeartbeatException(String message) {
    super(message);
  }

  public HoodieHeartbeatException(String message, Throwable t) {
    super(message, t);
  }

  public HoodieHeartbeatException(Throwable t) {
    super(t);
  }

}
